package
Version:
v0.0.0-...-5016079
Opens a new window with list of versions in this module.
Published: Nov 3, 2024
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Asset struct {
Id int64 `json:"id"`
Name string `json:"name"`
Description string `json:"description"`
Price float32 `json:"price"`
Owner_id int64 `json:"owner_id"`
}
type Credentials struct {
Username string `json:"username"`
Password string `json:"password"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.